@@ -8,7 +8,12 @@ try:
 except AttributeError:
     pass
 
-from YAFPA.common import file_checking as check, convert_all as all, convert_one as one, setup_config as setup
+from YAFPA.common import (
+    file_checking as check,
+    convert_all as all,
+    convert_one as one,
+    setup_config as setup,
+)
 
 
 def mobile_shortcuts(file="0"):
@@ -58,11 +63,12 @@ def main():
     parser.add_argument(
         "--keep",
         "--k",
+        "--K",
         help="Keep deleted file from vault and removed shared file",
         action="store_true",
     )
     parser.add_argument(
-        "--config", "--c", help="Edit the config file", action="store_true"
+        "--config", "--c", "--C", help="Edit the config file", action="store_true"
     )
     args = parser.parse_args()
     ori = args.filepath
@@ -75,6 +81,7 @@ def main():
         setup.create_env()
         return
     if not args.keep:
+
         check.delete_not_exist()
         stop_share = 1
     else:
@@ -86,6 +93,7 @@ def main():
             print(f"Error : {ori} doesn't exist.")
             return
     else:
+        pass
         all.convert_all(delopt, ng, force, stop_share)
 
 
