@@ -5,7 +5,11 @@ from pathlib import Path
 import frontmatter
 import yaml
 
-from YAFPA.common import file_checking as checkFile, conversion as convert, metadata as mt
+from YAFPA.common import (
+    file_checking as checkFile,
+    conversion as convert,
+    metadata as mt,
+    )
 from YAFPA.common import global_value
 
 BASEDIR = global_value.BASEDIR
@@ -21,13 +25,12 @@ def diff_file(file, folder, update=0):
         retro_old = checkFile.retro(notes_path)
         meta_old = frontmatter.load(notes_path)
         meta_old = mt.remove_frontmatter(meta_old.metadata)
-
         temp = convert.file_convert(file, folder)
         try:
             front_temp = frontmatter.loads("".join(temp))
         except yaml.parser.ParserError:
             print("ERROR : ", file)
-            pass
+            return False  # skip
         meta_new = mt.remove_frontmatter(front_temp.metadata)
         new_version = checkFile.retro(temp, 1)
         if new_version == retro_old and sorted(meta_old.keys()) == sorted(
@@ -44,7 +47,7 @@ def search_share(option=0, stop_share=1):
     filespush = []
     check = False
     folder = "_notes"
-    for sub, dirs, files in os.walk(vault):
+    for sub, dirs, files in os.walk(Path(vault)):
         for file in files:
             filepath = sub + os.sep + file
             if filepath.endswith(".md") and "excalidraw" not in filepath:
@@ -57,7 +60,10 @@ def search_share(option=0, stop_share=1):
                         folder = checkFile.check_folder("_notes")
                     if "share" in yaml_front.keys() and yaml_front["share"] is True:
                         if option == 1:
-                            if "update" in yaml_front and yaml_front["update"] is False:
+                            if (
+                                "update" in yaml_front.keys()
+                                and yaml_front["update"] is False
+                            ):
                                 update = 1
                             else:
                                 update = 0
@@ -72,24 +78,28 @@ def search_share(option=0, stop_share=1):
                             contents = convert.file_convert(filepath, folder)
                             check = convert.file_write(filepath, contents, folder)
                         destination = checkFile.dest(filepath, folder)
+                        msg_folder = os.path.basename(folder)
                         if check:
-                            filespush.append(f"Added : {os.path.basename(destination).replace('.md', '')} in {folder}")
+                            filespush.append(
+                                f"Added : {os.path.basename(destination).replace('.md', '')} in [{msg_folder}]"
+                            )
                     else:
                         if stop_share == 1:
                             if checkFile.delete_file(filepath, folder):
+                                msg_folder = os.path.basename(folder)
                                 destination = checkFile.dest(filepath, folder)
-                                filespush.append(f"Removed : {os.path.basename(destination).replace('.md', '')} from {folder}")
+                                filespush.append(
+                                    f"Removed : {os.path.basename(destination).replace('.md', '')} from [{msg_folder}]"
+                                )
 
                 except (
                     yaml.scanner.ScannerError,
                     yaml.constructor.ConstructorError,
                 ) as e:
                     pass
-
     return filespush, folder
 
 
-
 def convert_all(delopt=False, git=False, force=False, stop_share=0):
     if git:
         git_info = "NO PUSH"
@@ -112,13 +122,13 @@ def convert_all(delopt=False, git=False, force=False, stop_share=0):
         )
         new_files, priv = search_share(1, stop_share)
     if len(new_files) > 0:
-        add=""
+        add = ""
         rm = ""
         for md in new_files:
             if "removed" in md.lower():
-                rm = rm + "\n - " +  md.replace('Removed : ', '')
+                rm = rm + "\n - " + md.replace("Removed : ", "")
             elif "added" in md.lower():
-                add = add + "\n - " + md.replace('Added : ', '')
+                add = add + "\n - " + md.replace("Added : ", "")
         if len(rm) > 0:
             rm = f"🗑️ Removed from blog : {rm}"
         if len(add) > 0:
